function GraphemeColor(subjectName)
%GraphemeColor: allows subjects to match colors to synesthetic percepts of
%graphemes.
%Note: if the subject realizes s/he has made a mistake in a letter (ie, hit the spacebar
%when s/he wasn't ready or chose No Color by accident), you can run
%the graphemeColorREDO program just for those graphemes
%
%This program is part of the TexSyn Toolbox developed by David Eagleman,PhD
%eagleman@synesthete.org
%Full package freely downloadable from www.synesthete.org

thisfcn = 'GraphemeColor';
rootdir = setrootdir(thisfcn);

if nargin < 1,
    parameters = inputdlg('Subject initials:','TexSyn Toolbox',1);
    pause(0.5);
    subjectName = parameters{1};
end
myfilename = getSafeFilename(thisfcn,subjectName); %this will be used to save results

numTrials = 108; %108 trials - 3 for each of 36 graphemes
data=zeros (numTrials,4); %data matrix is 108 rows, 4 columns.  first column is the grapheme, 2:4 are the r g b values.

theGraphemes = char([48:57 65:90]); %this makes the char array 0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ
vec=Shuffle([theGraphemes theGraphemes theGraphemes]);  %shuffle up the order of the 3 x graphemes

data(:,1)=vec'; %puts the characters into the first column of the data matrix in the shuffled order in which they will be presented.

figure(1); %named figure 1 so that it doesn't interfere with the other figures called in "palettemaker"
set(gcf, 'Position', [100 50 1150 350]);
set(gcf,'Name','Texas Synesthesia Battery');

for i=1:numTrials %for each trial
    figure(1); %calls figure 1 to the forefront
    text(.5,.5,vec(i),'Fontsize', 50); %displays the grapheme
    axis off;
   [r,g,b] = Palettemaker; %calls the palettemaker function to show the color palette.  the palettemaker function returns the r g b values
  %the subject clicks in the color palette to get a color to appear in the
  %swatch, and uses the right and left arrow keys to make the color lighter
  %or darker.  when he is done, he presses the spacebar to register his
  %answer.
    data(i,2:4)=[r,g,b]; %put r g b values in data matrix
    figure(1);
    clf;
    text(.5,.5,'XXXXXXX','Fontsize', 50);  %display x's so that the subject knows the trial is over
    axis off;
    pause(0.1);
    clf;
    save(myfilename, 'data');   %save the data matrix after each trial
end
close(2); %close the second figure, which is a figure created in the palettemaker function
text(.01,.5,'Thank You for your participation','Fontsize', 50);
text(.3,.3,'Hit any key to exit', 'Fontsize', 15);
axis off;

GraphemeDisplay(subjectName); %calls display function.  
%if the subject realizes he has made a mistake in a letter (ie, hit the spacebar
%when he wasn't ready or chose no color by accident), you can let him do
%the graphemeColorREDO program
pause; %hit any key to close the figure
close(gcf);