function GraphemeColorRedo(subjectName, redovec, wrongTrials)
%GraphemeColorRedo: allows subjects to re-match colors to synesthetic percepts of
%graphemes when the subject realizes s/he has made a mistake in a letter.
%
%E.g., GraphemeColorRedo('dme', ['B' '3'], [1 2])
%Note: in GraphemeDisplay, the colors go from bottom to top, so the bottom row
%is trial 1, the middle row is trial 2, and the top row is trial 3
%
%This program is part of the TexSyn Toolbox developed by David Eagleman,PhD
%eagleman@synesthete.org
%Full package freely downloadable from www.synesthete.org

thisfcn = 'GraphemeColorRedo';
rootdir = setrootdir(thisfcn);

if nargin<1
    prompt = {'Subject name:','Which grapheme to retest (ex. F3K):','Which trial number (ex. [2 1 3]):'};
    dlg_title = 'TexSyn Toolbox';
    num_lines = 1;
    def = {'','','',''};
    parameters = inputdlg(prompt,dlg_title,num_lines,def);
    pause(0.5);
    subjectName = parameters{1};
    redovec = parameters{2};
    wrongTrials = str2num(parameters{3});
end

numTrials = length(redovec);
%load their data matrix for the original test
myfilename = [rootdir 'Data\GraphemeColorResults_' subjectName '.mat']
load(myfilename)

vec=shuffle(redovec);

for i=1:numTrials
    figure(1);
    set(gcf, 'Position', [100 50 1150 350]);
    set(gcf,'Name','Synesthesia Testing');
    text(.5,.5,vec(i),'Fontsize', 50);
    axis off;
    [r, g, b] = Palettemaker;
    [row, column]=find(data==(vec(i)));  %find the rows and columns of the data matrix where the grapheme is the one you want to reassign
    %there should be 3 different row-column pairs because there are 3
    %trials with that grapheme
    data(row(wrongTrials(i)),2:4)=[r,g,b]  %replace the r g b value for the mistake trial
    sprintf('Replaced row %d', wrongTrials(i));
    figure(1);
    clf;
    text(.5,.5,'XXXXXXX','Fontsize', 50);
    axis off;
    pause(0.1);
    clf;
end
close(2);
text(.05,.5,'Thank you for your participation','Fontsize', 50);
axis off;

myfilename = getSafeFilename('GraphemeColor',subjectName);   %this saves the file in the Data directory, making sure not to overwrite
save(myfilename);

pause;
close(gcf);