function GraphemeContrastColor(subjectName, lettervec)
%GraphemeContrastColor: allows subjects to match colors to synesthetic percepts of
%graphemes presented at different contrasts.
%
%E.g., GraphemeContrastColor('test', ['F' 'B' '3'])
%
%This program is part of the TexSyn Toolbox developed by David Eagleman,PhD
%eagleman@synesthete.org
%Full package freely downloadable from www.synesthete.org

thisfcn = 'GraphemeContrastColor';
rootdir = setrootdir(thisfcn);

if nargin < 1,
    parameters = inputdlg({'Subject initials:','Which graphemes to test:'},'graphemeContrastColor',1,{'','FB3'});
    pause(0.5);
    subjectName = parameters{1};
    lettervec = parameters{2};
end


contrasts = [1, 0.92, 0.84, 0.76, 0.69, 0.61, 0.0];

%generate all possible trial combinations here
numcont=length(contrasts)

numltrs=length(lettervec)

for i=1:numcont
    trialChoices((i-1)*numltrs+1:(i-1)*numltrs+numltrs)=lettervec
end

for i=1:numltrs
    trialChoicesContrast((i-1)*numcont+1:(i-1)*numcont+numcont)=contrasts
end

numTrials = length(lettervec) * length(contrasts);

trialvec = 1:numTrials;
trialvec = shuffle(trialvec);  %present these trials in a random order

for i=1:numTrials
    whichLetter = trialChoices(trialvec(i));
    whichContrast = trialChoicesContrast(trialvec(i));
    figure(1);
    set(gcf, 'Position', [100 50 1150 350]);
    set(gcf,'Name','TexSyn Toolbox');
    text(.5,.5, whichLetter,'Fontsize', 50, 'color', [whichContrast whichContrast whichContrast]);
    axis off;
    [r, g, b] = Palettemaker;
    %[row, column]=find(data==(vec(i)));  %find the rows and columns of the data matrix where the grapheme 
    %is the one you want to reassign there should be 3 different row-column pairs because there are 3
    %trials with that grapheme
    data(i, 1:5) = [double(whichLetter), r,g,b, whichContrast];  
    figure(1);
    clf;
    text(.5,.5,'XXXXXXX','Fontsize', 50);
    axis off;
    pause(0.1);
    clf;
end
close(2);
text(.05,.5,'Thank you for your participation.','Fontsize', 50);
axis off;

myfilename = getSafeFilename(thisfcn,subjectName) %this will be used to save results
save(myfilename, 'data', 'lettervec', 'contrasts')

%pause;
close(gcf);

GraphemeContrastDisplay(subjectName)

