function GraphemeContrastDisplay(subjectName)
%GraphemeContrastDisplay: displays the matched colors to 
%synesthetic percepts of graphemes presented at different contrasts.
%
%This program is part of the TexSyn Toolbox developed by David Eagleman,PhD
%eagleman@synesthete.org
%Full package freely downloadable from www.synesthete.org

if nargin < 1,
    parameters = inputdlg('Subject initials:','TexSyn Toolbox',1);
    pause(0.5);
    subjectName = parameters{1};
end

%load the subject's colors
rootdir = setrootdir('GraphemeContrastDisplay');
myfilename = [rootdir 'Data\GraphemeContrastColorResults_' subjectName '.mat']
load(myfilename);

%sort the data matrix
data=sortrows(data);

%display the letters and numbers
figure;
set(gcf, 'Position', [0 100 1200 300]);
set(gcf,'Name','Grapheme-Color Contrast Synesthesia Results');
%title(subjectName);

subplot(2,1,2);

% for trial = 1:length(data)
for j = 1:length(contrasts);
    myrows = find(data(:,5) == contrasts(j));   %this picks out the trials with a certain contrast
    data(myrows,:)
    
    
    for i = 1:length(myrows)   %how many tests at this contrast
        if data(myrows(i), 2) > -1
            text(0.01 + 0.0915*j, 0.15+(i-1)*0.35, char(data(myrows(i),1)),'Fontsize', 20, 'Color', data(myrows(i),2:4));
        end
    end
    mycontrast = data(myrows(1),5);
    text(-0.01 + 0.0915*j, 0.15+(i)*0.35, char(149), 'Fontsize', 100, 'Color', [mycontrast mycontrast mycontrast]);  %cameron: this will draw a circle
%     text(0.01 + 0.0915*j, 0.15+(i)*0.35, char(46), 'Fontsize', 300, 'Color', [mycontrast mycontrast mycontrast]);  %cameron: this will draw a square
end
% end

%     for i=1:3:length(data)
%         if data([i+trial-1], 2) > -1
%             text(0.01 + 0.00915*i, 0.15+(trial-1)*0.35, char(data(i,1)),'Fontsize', 20, 'Color', data([i+trial-1],2:4));
%         end
%     end
% end 
axis off;


% 
% counter=0;
% %numColor=0;
% for i=1:3:length(data)
%     t=(i+2)/3;
%     r=abs(newdata(i,2)-newdata(i+1,2)) + abs(newdata(i+2,2)-newdata(i+1,2)) + abs(newdata(i+2,2)-newdata(i,2));
%     g=abs(newdata(i,3)-newdata(i+1,3)) + abs(newdata(i+2,3)-newdata(i+1,3)) + abs(newdata(i+2,3)-newdata(i,3));
%     b=abs(newdata(i,4)-newdata(i+1,4)) + abs(newdata(i+2,4)-newdata(i+1,4)) + abs(newdata(i+2,4)-newdata(i,4));
%     diffMatrix(t,1)=r+g+b;
%  
%     if newdata(i,2) > -1  %as long as they didn't choose "no color"
%        counter=counter+1;
%        %numColor=numColor+1;
%     end
% end
% counter

% diffScore=sum(diffMatrix)/counter;
% subplot(2,1,1);
% bar(diffMatrix);
% axis([0 36.5 0 6]);
% mytitle = sprintf('%s Difference score = %.4f', subjectName, diffScore);
% title(mytitle);	
% axis off;  %ylabel('Color variability');
% text(-0.4, 2.0, 'Color')
% text(-0.4, 1.4, 'variability')

myfilename = sprintf('Z:\\share\\Synesthesia\\ColorGraphemeData\\%s.fig', subjectName);
saveas(gcf, myfilename);


        
        