function GraphemeDisplay(subjectName)
%GraphemeDisplay: displays the matched colors to synesthetic percepts of graphemes.
%
%This program is part of the TexSyn Toolbox developed by David Eagleman,PhD
%eagleman@synesthete.org
%Full package freely downloadable from www.synesthete.org

if nargin < 1,
    parameters = inputdlg('Subject initials:','TexSyn Toolbox: GraphemeDisplay',1);
    pause(0.5);
    subjectName = parameters{1};
end

%load the subject's colors
rootdir = setrootdir('GraphemeDisplay');
myfilename = [rootdir 'Data\GraphemeColorResults_' subjectName '.mat']
load(myfilename);

%sort the data matrix
newdata=sortrows(data);

%display the letters and numbers
figure;
set(gcf, 'Position', [0 100 1200 300]);
set(gcf,'Name','GraphemeColor Synesthesia Results');
%title(subjectName);

subplot(2,1,2);
for trial = 1:3
    for i=1:3:length(data)
        if newdata([i+trial-1], 2) > -1
            text(0.01 + 0.00915*i, 0.15+(trial-1)*0.35, char(newdata(i,1)),'Fontsize', 20, 'Color', newdata([i+trial-1],2:4));
        end
    end
end 
axis off;

counter=0;
for i=1:3:length(data)
    t=(i+2)/3;
    if newdata(i, 2) > -1 & newdata(i+1, 2) > -1 & newdata(i+2, 2) > -1 %as long as they didn't choose "no color"    
        r=abs(newdata(i,2)-newdata(i+1,2)) + abs(newdata(i+2,2)-newdata(i+1,2)) + abs(newdata(i+2,2)-newdata(i,2));
        g=abs(newdata(i,3)-newdata(i+1,3)) + abs(newdata(i+2,3)-newdata(i+1,3)) + abs(newdata(i+2,3)-newdata(i,3));
        b=abs(newdata(i,4)-newdata(i+1,4)) + abs(newdata(i+2,4)-newdata(i+1,4)) + abs(newdata(i+2,4)-newdata(i,4));
        diffMatrix(t,1)=r+g+b;
        counter=counter+1; %counter will represent the row with the most colored graphemes
    else
        diffMatrix(t,1)=NaN;  %if they chose 'No Color', it is not counted in the color variability score
    end
end
counter
diffMatrix

diffScore=sum(diffMatrix(~isnan(diffMatrix)))/counter  %this sum excludes anything that is not a number
subplot(2,1,1);
bar(diffMatrix);
axis([0 36.5 0 6]);
mytitle = sprintf('%s Difference score = %.4f', subjectName, diffScore);
title(mytitle);	
axis off;  %ylabel('Color variability');
text(-0.4, 2.0, 'Color')
text(-0.4, 1.4, 'variability')
