function MonthDisplay (subjectName)
%MonthDisplay: displays the matched colors to synesthetic percepts of months.
%
%This program is part of the TexSyn Toolbox developed by David Eagleman,PhD
%eagleman@synesthete.org
%Full package freely downloadable from www.synesthete.org

if nargin < 1,
    parameters = inputdlg('Subject initials:','TexSyn Toolbox',1);
    pause(0.5);
    subjectName = parameters{1};
end

%load the subject's colors
rootdir = setrootdir('MonthDisplay');
myfilename = [rootdir 'Data\MonthColorResults_' subjectName '.mat']
load(myfilename);

%sort the data matrix
newdata=sortrows(data);

counter=0;
for i=1:3:36
    t=(i+2)/3;
    r=abs(newdata(i,2)-newdata(i+1,2)) + abs(newdata(i+2,2)-newdata(i+1,2)) + abs(newdata(i+2,2)-newdata(i,2));
    g=abs(newdata(i,3)-newdata(i+1,3)) + abs(newdata(i+2,3)-newdata(i+1,3)) + abs(newdata(i+2,3)-newdata(i,3));
    b=abs(newdata(i,4)-newdata(i+1,4)) + abs(newdata(i+2,4)-newdata(i+1,4)) + abs(newdata(i+2,4)-newdata(i,4));
    sum1=r+g+b;
    diffMatrix(t,1)=sum1;
    counter=counter+1;
    if r==0 && g==0 && b==0
        counter=counter-1;
    end
end

months=char('January', 'February' , 'March' , 'April' , 'May',  'June' , 'July', 'August', 'September', 'October', 'November', 'December');

newsum=sum(diffMatrix);
diffScore=newsum/counter*10;

figure;
set(gcf, 'Position', [50 100 800 850]);
set(gcf,'Name','Month-Color Synesthesia Results');
mytitle = sprintf('%s Color Variability Score = %.2f', subjectName, diffScore);
title(mytitle, 'Fontsize', 20);	
axis off;

for trial = 1:3
    for i=1:3:36
        t=(i+2)/3;
        text((trial-1)*.26, .95+i*-0.028, months(newdata(i),:),'Fontsize', 20, 'Color', newdata([i+trial-1],2:4));
        text(.9, .95+i*-.028, num2str(diffMatrix(t,1)), 'Fontsize', 20)
        text(.79, .98, 'Color Variability Score', 'Fontsize', 20)
        text(.80, .95-37*.028, 'Total=', 'Fontsize', 20)
        text(.95, .95-37*.028, num2str(newsum), 'Fontsize', 20)
    end
end 


