function SoundColor(subjectName)
%SoundColor: allows subjects to match colors to synesthetic percepts of
%sounds.
%Note: if the subject realizes s/he has made a mistake in a letter (ie, hit the spacebar
%when s/he wasn't ready or chose No Color by accident), you can run
%the SoundColorREDO program just for those sounds
%
%This program is part of the TexSyn Toolbox developed by David Eagleman,PhD
%eagleman@synesthete.org
%Full package freely downloadable from www.synesthete.org
%
%     '1'     'TwenCentFox'    '24000'
%     '2'     'Boxer'          '24000'
%     '3'     'Seductive'      '22000'
%     '4'     'Airport'        '30000'
%     '5'     'Hitchcock'      '26000'
%     '6'     'Applause'       '26000'
%     '7'     'Bee'            '20000'
%     '8'     'Bird'           '28000'
%     '9'     'Bleep'          '10000'
%     '10'    'Bluejay'        '9000' 
%     '11'    'Boing'          '28000'
%     '12'    'Classictwo'     '19000'
%     '13'    'Bottle'         '15000'
%     '14'    'Bubble'         '20000'
%     '15'    'Coke'           '24000'
%     '16'    'TOverture'      '22000'
%     '17'    'Buzzer'         '17000'
%     '18'    'Cello'          '24000'
%     '19'    'Guitar'         '22000'
%     '20'    'Haydn'          '18000'
%     '21'    'Horse'          '20000'
%     '22'    'Entertainer'    '24000'
%     '23'    'Giggling'       '24000'
%     '24'    'Ouch'           '30000'
%     '25'    'Plop'           '22000'
%     '26'    'DrumsN'         '22000'
%     '27'    'Engine'         '22000'
%     '28'    'Elephant'       '20000'
%     '29'    'Chirps'         '20000'

thisfcn = 'SoundColor';
rootdir = setrootdir(thisfcn);

if nargin < 1,
    parameters = inputdlg('Subject initials:','TexSyn Toolbox',1);
    pause(0.5);
    subjectName = parameters{1};
end
myfilename = getSafeFilename(thisfcn,subjectName); %this will be used to save results

numPieces=29;
disp('Please wait while the sound files load...');
soundsvec = [1:numPieces 1:numPieces 1:numPieces];
soundsvec = shuffle(soundsvec);
load([rootdir 'sounds.mat']);

data=zeros(numPieces*3,4);

figure(1);
    set(gcf, 'Position', [100 50 1150 350]);
    set(gcf,'Name','Music Synesthesia Testing');
    set(gcf,'Color','white');

    text(.02,.8,'Instructions: Please listen to the sounds and choose a ','Fontsize', 30);
    text(.02,.6,'color that best matches the synesthetic color you see','Fontsize', 30);
    text(.35,.1,'Hit any key to begin','Fontsize', 20);
    axis off;
    pause;
    clf;
    text(.03,.5,'Please select a color that best matches the sound','Fontsize', 20);
    text(.03,.7,'Hit the spacebar to register your answer','Fontsize', 20);
    axis off;
for i=1:(numPieces*3)
    data(i,1) = soundsvec(i);
    figure(1);
    wavplay(eval(char(sounds(soundsvec(i),2))), eval(char(sounds(soundsvec(i),3))));
    [r,g, b] = Palettemaker;
    data(i,2:4)=[r,g,b];
end
close(2);
clf;
text(.05,.5,'Thank you for your participation','Fontsize', 50);
text(.35,.1,'Hit any key to exit','Fontsize', 10);
axis off;

data
myfilename = getSafeFilename(thisfcn,subjectName); %this will be used to save results
%myfilename = [rootdir 'Data\SoundColorResults_' subjectName '%s.mat'];
save(myfilename, 'data');

SoundDisplay(subjectName);

pause;
close(gcf);

